@@ -1,4 +1,4 @@
-from main import BASE_URL, _format_http_response, get_headers
+from superpowered.main import BASE_URL, _format_http_response, get_headers
 import requests
 import random
 import string
